# ToDoManager
Human readble command line task manager

### Example commands
```
todo add "read a book"
todo list
todo check 1
todo delete 0
```

**ToDoManager** automatically create and stores all your tasks in YAML files.
You can find all your daylogs in the `$HOME/Documents/todo`

```
/home/alex/Documents/todo
├── 2024-06-04.yaml
└── 2024-06-05.yaml
```

Each **YAML** file represents a new **daylog**, containing all your tasks for a specific day


